Chad has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/92590


Change subject: Rename wfIsHipHop() to wfIsHHVM()
......................................................................

Rename wfIsHipHop() to wfIsHHVM()

The former is only really used to refer to the older hphp compiler.
Now all docs pretty much exclusively are referring to HHVM and
that's the project's name going forward.

Only affected extension (in Git or SVN) is GWToolset, fixing in
I3a490ef.

Change-Id: I81e4ce5d14e344e67045050261f91b3c0159f222
---
M includes/GlobalFunctions.php
M includes/Init.php
M includes/specials/SpecialUpload.php
M includes/upload/UploadBase.php
M maintenance/eval.php
5 files changed, 6 insertions(+), 6 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/90/92590/1

diff --git a/includes/Init.php b/includes/Init.php
index 64431f0..dd5e2d7 100644
--- a/includes/Init.php
+++ b/includes/Init.php
@@ -48,7 +48,7 @@
         * @return bool
         */
        static function isHipHop() {
-               return defined( 'HPHP_VERSION' );
+               return wfIsHHVM();
        }
 
        /**
diff --git a/includes/specials/SpecialUpload.php 
b/includes/specials/SpecialUpload.php
index 09facf4..b79aaa9 100644
--- a/includes/specials/SpecialUpload.php
+++ b/includes/specials/SpecialUpload.php
@@ -812,7 +812,7 @@
                $this->mMaxUploadSize['file'] = UploadBase::getMaxUploadSize( 
'file' );
                # Limit to upload_max_filesize unless we are running under 
HipHop and
                # that setting doesn't exist
-               if ( !wfIsHipHop() ) {
+               if ( !wfIsHHVM() ) {
                        $this->mMaxUploadSize['file'] = min( 
$this->mMaxUploadSize['file'],
                                wfShorthandToInteger( ini_get( 
'upload_max_filesize' ) ),
                                wfShorthandToInteger( ini_get( 'post_max_size' 
) )
diff --git a/includes/upload/UploadBase.php b/includes/upload/UploadBase.php
index 2260241..b162de2 100644
--- a/includes/upload/UploadBase.php
+++ b/includes/upload/UploadBase.php
@@ -105,7 +105,7 @@
                }
 
                # Check php's file_uploads setting
-               return wfIsHipHop() || wfIniGetBool( 'file_uploads' );
+               return wfIsHHVM() || wfIniGetBool( 'file_uploads' );
        }
 
        /**
diff --git a/maintenance/eval.php b/maintenance/eval.php
index abedc61..e03763f 100644
--- a/maintenance/eval.php
+++ b/maintenance/eval.php
@@ -70,7 +70,7 @@
                readline_write_history( $historyFile );
        }
        $val = eval( $line . ";" );
-       if ( wfIsHipHop() || is_null( $val ) ) {
+       if ( wfIsHHVM() || is_null( $val ) ) {
                echo "\n";
        } elseif ( is_string( $val ) || is_numeric( $val ) ) {
                echo "$val\n";

diff --git a/includes/GlobalFunctions.php b/includes/GlobalFunctions.php
index 77c09e5..c10e5cc 100644
--- a/includes/GlobalFunctions.php
+++ b/includes/GlobalFunctions.php
@@ -2450,11 +2450,11 @@
 }
 
 /**
  * Check if we are running under HipHop
  *
  * @return Bool
  */
-function wfIsHipHop() {
+function wfIsHHVM() {
        return defined( 'HPHP_VERSION' );
 }
 
@@ -2450,11 +2450,11 @@
 
 /**
- * Check if we are running under HipHop
+ * Check if we are running under HHVM
  *
  * @return Bool
-- 
To view, visit https://gerrit.wikimedia.org/r/92590
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I81e4ce5d14e344e67045050261f91b3c0159f222
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Chad <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to